@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.020;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Carp qw(cluck confess);
 use JSON;
@@ -16,11 +16,11 @@ use Travel::Status::DE::DBWagenreihung::Wagon;
 sub new {
 	my ( $class, %opt ) = @_;
 
-	if ( not $opt{train_number} ) {
+	if ( not $opt{train_number} and not $opt{from_json} ) {
 		confess('train_number option must be set');
 	}
 
-	if ( not $opt{departure} ) {
+	if ( not $opt{departure} and not $opt{from_json} ) {
 		confess('departure option must be set');
 	}
 
@@ -30,6 +30,7 @@ sub new {
 		developer_mode => $opt{developer_mode},
 		cache          => $opt{cache},
 		departure      => $opt{departure},
+		from_json      => $opt{from_json},
 		json           => JSON->new,
 		serializable   => $opt{serializable},
 		train_number   => $opt{train_number},
@@ -62,15 +63,19 @@ sub get_wagonorder {
 		$datetime = $datetime->strftime('%Y%m%d%H%M');
 	}
 
-	my ( $content, $err )
-	  = $self->get_with_cache( $cache,
-		"${api_base}/${train_number}/${datetime}" );
+	my $json = $self->{from_json};
 
-	if ($err) {
-		$self->{errstr} = "Failed to fetch station data: $err";
-		return;
+	if ( not $json ) {
+		my ( $content, $err )
+		  = $self->get_with_cache( $cache,
+			"${api_base}/${train_number}/${datetime}" );
+
+		if ($err) {
+			$self->{errstr} = "Failed to fetch station data: $err";
+			return;
+		}
+		$json = $self->{json}->utf8->decode($content);
 	}
-	my $json = $self->{json}->utf8->decode($content);
 
 	if ( exists $json->{error} ) {
 		$self->{errstr} = 'Backend error: ' . $json->{error}{msg};
@@ -97,6 +102,12 @@ sub errstr {
 sub direction {
 	my ($self) = @_;
 
+	if ( not exists $self->{direction} ) {
+
+		# direction is set while parsing wagons
+		$self->wagons;
+	}
+
 	return $self->{direction};
 }
 
@@ -425,7 +436,7 @@ Travel::Status::DE::DBWagenreihung - Interface to Deutsche Bahn Wagon Order API.
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
